dev library
Developer tooling for SQLite Loom projects.
Application runtime code should normally import sqlite_loom.dart instead.
Classes
- LoomExitCode
- Stable process exit codes emitted by the project CLI.
- LoomFlavorSelection
- A selected SQLite Loom flavor plus arguments for the database command.
- LoomProjectConfig
-
Parsed
sqlite_loom.yamlproject configuration.
Functions
-
runSqliteLoomProjectCli(
List< String> arguments, {Directory? currentDirectory, LoomCliWriter out = print, LoomCliWriter error = _stderr, LoomClock clock = _utcNow, LoomProcessRunner processRunner = _inheritProcess}) → Future<int> - Runs SQLite Loom's project-aware developer CLI.
Typedefs
- LoomCliWriter = void Function(String message)
- Output callback used by the project CLI.
- LoomClock = DateTime Function()
- Time source used to create deterministic timestamp migration versions.
-
LoomProcessRunner
= Future<
int> Function(String executable, List<String> arguments, {required String workingDirectory}) - Runs a child process and returns its exit code.