LoomFlavorSelection class final

A selected SQLite Loom flavor plus arguments for the database command.

Constructors

LoomFlavorSelection({required String name, required String databasePath, required String environment, required bool allowDestructive, required List<String> arguments})
const
LoomFlavorSelection.load(List<String> arguments, {required File projectFile, Map<String, String>? environmentVariables})
Loads inline flavor defaults from projectFile and an optional override.
factory

Properties

allowDestructive bool
final
arguments List<String>
final
databasePath String
final
environment String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited