LoomProjectConfig class final

Parsed sqlite_loom.yaml project configuration.

Properties

configFile File
final
defaultFlavor String
final
flavorOverridesDirectory Directory
final
hashCode int
The hash code for this object.
no setterinherited
indexFile File
final
lockFile File
final
migrationsDirectory Directory
final
packageName String
final
root Directory
final
runnerFile File
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

discover(Directory start, {String? explicitPath}) LoomProjectConfig
Finds and parses project configuration, searching parent directories.