DbMigration class abstract

A versioned, ordered database schema change.

Implementers

Constructors

DbMigration()
Creates a migration.
const

Properties

checksum String?
Optional stable checksum used to detect edited released migrations.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
A stable descriptive name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
The unique positive version number.
no setter

Methods

down(DbMigrationContext migration) FutureOr<void>
Reverses this migration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
up(DbMigrationContext migration) FutureOr<void>
Applies this migration.

Operators

operator ==(Object other) bool
The equality operator.
inherited