DbMigrationContext class final
Transaction-bound helpers available while a migration is running.
- Implemented types
Properties
- database → Database
-
Get the database.
no setteroverride
- executor → DatabaseExecutor
-
The exact executor owned by the migrator, normally a transaction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → DbSchema
-
Type-safe schema operations bound to executor.
final
Methods
-
batch(
) → Batch -
Creates a batch, used for performing multiple operation
in a single atomic operation.
override
-
delete(
String table, {String? where, List< Object?> ? whereArgs}) → Future<int> -
Convenience method for deleting rows in the database.
override
-
execute(
String sql, [List< Object?> ? arguments]) → Future<void> -
Executes a single SQL statement with no return value.
override
-
insert(
String table, Map< String, Object?> values, {String? nullColumnHack, ConflictAlgorithm? conflictAlgorithm}) → Future<int> -
This method helps insert a map of
valuesinto the specifiedtableand returns the id of the last inserted row.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String table, {bool? distinct, List< String> ? columns, String? where, List<Object?> ? whereArgs, String? groupBy, String? having, String? orderBy, int? limit, int? offset}) → Future<List< Map< >String, Object?> > -
This is a helper to query a table and return the items found. All optional
clauses and filters are formatted as SQL queries
excluding the clauses' names.
override
-
queryCursor(
String table, {bool? distinct, List< String> ? columns, String? where, List<Object?> ? whereArgs, String? groupBy, String? having, String? orderBy, int? limit, int? offset, int? bufferSize}) → Future<QueryCursor> -
See DatabaseExecutor.rawQueryCursor for details about the argument
bufferSizeSee DatabaseExecutor.query for the other arguments.override -
rawDelete(
String sql, [List< Object?> ? arguments]) → Future<int> -
Executes a raw SQL DELETE query and returns the
number of changes made.
override
-
rawInsert(
String sql, [List< Object?> ? arguments]) → Future<int> -
Executes a raw SQL INSERT query and returns the last inserted row ID.
override
-
rawQuery(
String sql, [List< Object?> ? arguments]) → Future<List< Map< >String, Object?> > -
Executes a raw SQL SELECT query and returns a list
of the rows that were found.
override
-
rawQueryCursor(
String sql, List< Object?> ? arguments, {int? bufferSize}) → Future<QueryCursor> -
Executes a raw SQL SELECT with a cursor.
override
-
rawUpdate(
String sql, [List< Object?> ? arguments]) → Future<int> -
Executes a raw SQL UPDATE query and returns
the number of changes made.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String table, Map< String, Object?> values, {String? where, List<Object?> ? whereArgs, ConflictAlgorithm? conflictAlgorithm}) → Future<int> -
Convenience method for updating rows in the database. Returns
the number of changes made
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited