SqliteLoomTestHarness class final
Properties
- database → Database
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loom → SqliteLoom
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
open(
{required Future< Database> openDatabase(), Iterable<DbMigration> migrations = const []}) → Future<SqliteLoomTestHarness>